@@ -58,7 +58,7 @@ has types     => sub { Mojolicious::Types->new };
 has validator => sub { Mojolicious::Validator->new };
 
 our $CODENAME = 'Doughnut';
-our $VERSION  = '7.37';
+our $VERSION  = '7.38';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -539,6 +539,9 @@ L<Mojolicious::Static> object.
   # Add another class with static files in DATA section
   push @{$app->static->classes}, 'Mojolicious::Plugin::Fun';
 
+  # Remove built-in favicon
+  delete $app->static->extra->{'favicon.ico'};
+
 =head2 types
 
   my $types = $app->types;
@@ -1090,6 +1093,8 @@ Viliam Pucik
 
 Wes Cravens
 
+William Lindley
+
 Yaroslav Korshak
 
 Yuki Kimoto
